@@ -10,9 +10,11 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpire
 import org.gcube.portlets.user.td.gwtservice.shared.tr.normalization.NormalizationSession;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.tablewidget.client.TableWidgetMessages;
 import org.gcube.portlets.user.td.tablewidget.client.properties.ColumnDataProperties;
 import org.gcube.portlets.user.td.tablewidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.tablewidget.client.util.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
@@ -64,28 +66,30 @@ import com.sencha.gxt.widget.core.client.grid.Grid;
  */
 public class NormalizePanel extends FramedPanel implements
 		MonitorDialogListener {
-	protected String WIDTH = "640px";
-	protected String HEIGHT = "520px";
+	private static final String WIDTH = "640px";
+	private static final String HEIGHT = "520px";
 
-	protected TRId trId;
-	protected EventBus eventBus;
-	protected ArrayList<String> rows;
+	private TRId trId;
+	private EventBus eventBus;
 
-	protected NormalizationSession normalizationSession;
+	private NormalizationSession normalizationSession;
 
-	protected ListLoader<ListLoadConfig, ListLoadResult<ColumnData>> loader;
-	protected Grid<ColumnData> grid;
-	protected CheckBoxSelectionModel<ColumnData> sm;
-	protected FieldLabel columnsSelectLabel;
-	protected TextButton normalizeButton;
-	protected TextField normalizedColumnName;
-	protected TextField valueColumnName;
-	protected NormalizeDialog parent;
+	private ListLoader<ListLoadConfig, ListLoadResult<ColumnData>> loader;
+	private Grid<ColumnData> grid;
+	private CheckBoxSelectionModel<ColumnData> sm;
+	private TextButton btnNormalize;
+	private TextField normalizedColumnName;
+	private TextField valueColumnName;
+	private NormalizeDialog parent;
+
+	private CommonMessages msgsCommon;
+	private TableWidgetMessages msgs;
 
 	public NormalizePanel(NormalizeDialog parent, TRId trId, EventBus eventBus) {
 		this.parent = parent;
 		this.trId = trId;
 		this.eventBus = eventBus;
+		initMessages();
 		create();
 	}
 
@@ -93,9 +97,16 @@ public class NormalizePanel extends FramedPanel implements
 		this.trId = trId;
 		this.eventBus = eventBus;
 		this.parent = null;
+		initMessages();
 		create();
 	}
 
+	protected void initMessages() {
+		msgsCommon = GWT.create(CommonMessages.class);
+		msgs = GWT.create(TableWidgetMessages.class);
+
+	}
+
 	protected void create() {
 		Log.debug("Create NormalizationPanel(): [" + trId.toString() + "]");
 
@@ -105,10 +116,10 @@ public class NormalizePanel extends FramedPanel implements
 		setBodyBorder(false);
 
 		// Normalize Button
-		normalizeButton = new TextButton("Normalize");
-		normalizeButton.setIcon(ResourceBundle.INSTANCE.tableNormalize());
-		normalizeButton.setIconAlign(IconAlign.RIGHT);
-		normalizeButton.setTitle("Normalize");
+		btnNormalize = new TextButton(msgs.btnNormalizeText());
+		btnNormalize.setIcon(ResourceBundle.INSTANCE.tableNormalize());
+		btnNormalize.setIconAlign(IconAlign.RIGHT);
+		btnNormalize.setToolTip(msgs.btnNormalizeToolTip());
 
 		SelectHandler normalizeHandler = new SelectHandler() {
 
@@ -117,24 +128,25 @@ public class NormalizePanel extends FramedPanel implements
 
 			}
 		};
-		normalizeButton.addSelectHandler(normalizeHandler);
+		btnNormalize.addSelectHandler(normalizeHandler);
 
 		normalizedColumnName = new TextField();
 		FieldLabel normalizedColumnNameLabel = new FieldLabel(
-				normalizedColumnName, "Normalized column");
+				normalizedColumnName, msgs.normalizedColumnNameLabel());
 		normalizedColumnNameLabel.setLabelWidth(110);
 
 		valueColumnName = new TextField();
 		FieldLabel valueColumnNameLabel = new FieldLabel(valueColumnName,
-				"Value column");
+				msgs.valueColumnNameLabel());
 		valueColumnNameLabel.setLabelWidth(110);
 
-		FieldLabel columnsLabel = new FieldLabel(null, "Columns to Normalize");
-		columnsLabel.setLabelWidth(150);
-		columnsLabel.getElement().applyStyles("font-weight:bold");
+		FieldLabel columnsToNormalizeLabel = new FieldLabel(null,
+				msgs.columnsToNormalizeLabel());
+		columnsToNormalizeLabel.setLabelWidth(150);
+		columnsToNormalizeLabel.getElement().applyStyles("font-weight:bold");
 
 		HBoxLayoutContainer hBox = new HBoxLayoutContainer();
-		hBox.add(normalizeButton, new BoxLayoutData(new Margins(2, 5, 2, 5)));
+		hBox.add(btnNormalize, new BoxLayoutData(new Margins(2, 5, 2, 5)));
 
 		// Grid ColumnData
 		ColumnDataProperties props = GWT.create(ColumnDataProperties.class);
@@ -198,8 +210,8 @@ public class NormalizePanel extends FramedPanel implements
 		v.setAdjustForScroll(true);
 		v.add(normalizedColumnNameLabel, new VerticalLayoutData(1, -1));
 		v.add(valueColumnNameLabel, new VerticalLayoutData(1, -1));
-		v.add(columnsLabel, new VerticalLayoutData(-1, -1, new Margins(2, 1, 5,
-				1)));
+		v.add(columnsToNormalizeLabel, new VerticalLayoutData(-1, -1,
+				new Margins(2, 1, 5, 1)));
 		v.add(grid, new VerticalLayoutData(1, -1, new Margins(0)));
 		v.add(hBox, new VerticalLayoutData(-1, -1, new Margins(10, 0, 10, 0)));
 		add(v, new VerticalLayoutData(1, -1, new Margins(0)));
@@ -229,17 +241,17 @@ public class NormalizePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("load columns failure:"
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error retrieving columns",
-										"Error retrieving columns");
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingColumns());
 							}
 						}
 
-						normalizeButton.disable();
+						btnNormalize.disable();
 						callback.onFailure(caught);
 					}
 
@@ -251,13 +263,13 @@ public class NormalizePanel extends FramedPanel implements
 									result));
 
 						} else {
-							normalizeButton.disable();
+							btnNormalize.disable();
 							Log.error("This tabular resource has not Integer or Numeric columns, normalize is not applicable!");
-							UtilsGXT3
-									.alert("Attention",
-											"This tabular resource has not Integer or Numeric columns, normalize is not applicable!");
+							UtilsGXT3.alert(
+									msgsCommon.attention(),
+									msgs.attentionThisTabularResourceHasNotIntegerOrNumericColumnsNormalizeIsNotApplicable());
 							callback.onFailure(new Throwable(
-									"This tabular resource has not Integer or Numeric columns, normalize is not applicable!"));
+									msgs.attentionThisTabularResourceHasNotIntegerOrNumericColumnsNormalizeIsNotApplicable()));
 						}
 
 					}
@@ -282,7 +294,8 @@ public class NormalizePanel extends FramedPanel implements
 	protected void onNormalize() {
 		ArrayList<ColumnData> col = getSelectedItems();
 		if (col == null || col.size() < 1) {
-			UtilsGXT3.alert("Attention", "Attention no column selected!");
+			UtilsGXT3.alert(msgsCommon.attention(),
+					msgs.attentionNoColumnSelected());
 			return;
 		}
 
@@ -301,17 +314,17 @@ public class NormalizePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Normalization Error: "
 											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error on Normalization",
+									UtilsGXT3.alert(msgsCommon.error(),
 											caught.getLocalizedMessage());
 								}
 							}
